package com.ebaiyihui.family.doctor.server.controller;


import com.ebaiyihui.family.doctor.common.dto.InvalidMedicalRecordDTO;
import com.ebaiyihui.family.doctor.common.vo.PatientCaseDetail;
import com.ebaiyihui.family.doctor.server.entity.PatientSignEntity;
import com.ebaiyihui.family.doctor.server.exception.BusinessException;
import com.ebaiyihui.family.doctor.server.mapper.PatientSignMapper;
import com.ebaiyihui.family.doctor.server.service.HisTemplateService;
import com.ebaiyihui.family.doctor.server.service.PatientMedicalRecordService;
import com.ebaiyihui.framework.response.BaseResponse;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Objects;

@RestController
@RequestMapping("/medicalRecord")
@Api(tags = "患者病历API")
public class PatientMedicalRecordController {

    @Autowired
    private PatientMedicalRecordService patientMedicalRecordService;

    @Autowired
    private PatientSignMapper patientSignMapper;

    @Autowired
    private HisTemplateService hisTemplateService;

    /**
     * 根据admID查询病例
     * @param admId
     * @return
     */
    @PostMapping("/getMedicalInfoByAdmId")
    @ApiOperation(value = "根据admID查询病例")
    public BaseResponse<PatientCaseDetail> getMedicalInfoByAdmId(@RequestBody InvalidMedicalRecordDTO admId) {
        PatientCaseDetail medicalInfoByAdmId = patientMedicalRecordService.getMedicalInfoByAdmId(admId.getAdmId());
        return BaseResponse.success(medicalInfoByAdmId);
    }


    @ApiOperation(value = "推送病例卡片", notes = "医生开具复诊病例推送小卡片")
    @RequestMapping(value = "/treatmentCard", method = RequestMethod.POST)
    public BaseResponse<Object> treatmentCard(@RequestBody @Validated InvalidMedicalRecordDTO param,
                                            BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return BaseResponse.error(Objects.requireNonNull(bindingResult.getFieldError()).getDefaultMessage());
        }
        return patientMedicalRecordService.treatmentCard(param.getAdmId());
    }

    @ApiOperation(value = "获取患者医生信息", notes = "获取患者医生信息-医药云调用")
    @RequestMapping(value = "/getBaseInfoByAdmId", method = RequestMethod.POST)
    public BaseResponse<Object> getBaseInfoByAdmId(@RequestBody @Validated InvalidMedicalRecordDTO param,
                                              BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return BaseResponse.error(Objects.requireNonNull(bindingResult.getFieldError()).getDefaultMessage());
        }
        return patientMedicalRecordService.getBaseInfoByAdmId(param.getAdmId());
    }

    @ApiOperation(value = "手动挂号", notes = "手动给已签约的订单挂号云his")
    @RequestMapping(value = "/manualReg", method = RequestMethod.GET)
    public BaseResponse<Object> test(@RequestParam String admId) {
        PatientSignEntity patientSignEntity = patientSignMapper.queryByAdmId(admId);
        BaseResponse<Object> response = hisTemplateService.registrationAndTreatment(patientSignEntity);
        if (response.isSuccess()){
            patientSignEntity.setClinicCode(response.getData().toString());
        }else {
            throw new BusinessException("his挂号失败");
        }
        patientSignMapper.updateById(patientSignEntity);

        return BaseResponse.success();
    }
}
